@@ -3,9 +3,10 @@
 export XCODEDIR=$(xcode-select -p)
 export BASEDIR="${XCODEDIR}/Platforms/iPhoneOS.platform/Developer"
 export PATH="${BASEDIR}/usr/bin:$BASEDIR/usr/sbin:$PATH"
-export SDK="${BASEDIR}/SDKs/iPhoneOS7.1.sdk"
-export CFLAGS="-Oz -mthumb -arch armv7 -isysroot ${SDK}"
-export LDFLAGS="-mthumb -arch armv7 -isysroot ${SDK}"
+export SDK="${BASEDIR}/SDKs/iPhoneOS.sdk"
+export IPHONEOS_VERSION_MIN="5.1.1"
+export CFLAGS="-Oz -mthumb -arch armv7 -isysroot ${SDK} -miphoneos-version-min=${IPHONEOS_VERSION_MIN}"
+export LDFLAGS="-mthumb -arch armv7 -isysroot ${SDK} -miphoneos-version-min=${IPHONEOS_VERSION_MIN}"
 export PREFIX="$(pwd)/dnscrypt-proxy-ios"
 
 export SODIUM_IOS_PREFIX="/tmp/libsodium-ios"
